==> genometools-1.2.0.tar.gz: genometools-1.2.0/src/core/fastabuffer.h <==
/*
  Copyright (c) 2007 Stefan Kurtz <kurtz@zbh.uni-hamburg.de>
  Copyright (c) 2007 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef FASTABUFFER_H
#define FASTABUFFER_H

#include <stdbool.h>
#include "core/arraydef.h"
#include "core/filelengthvalues.h"
#include "core/queue.h"
#include "core/str_array.h"
#include "core/symboldef.h"

typedef struct GtFastaBuffer GtFastaBuffer;

GtFastaBuffer* gt_fastabuffer_new(const GtStrArray *filenametab,
                             const Uchar *symbolmap, bool plainformat,
                             Filelengthvalues **filelengthtab,
                             GtQueue *descptr,
                             unsigned long *characterdistribution);
static int   gt_fastabuffer_next(GtFastaBuffer*, Uchar *val, GtError*);
void         gt_fastabuffer_delete(GtFastaBuffer*);

#include "fastabuffer_imp.h"

#endif

==> genometools-1.3.4.tar.gz: genometools-1.3.4/src/core/fastabuffer.h <==
/*
  Copyright (c) 2007 Stefan Kurtz <kurtz@zbh.uni-hamburg.de>
  Copyright (c) 2007 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef FASTABUFFER_H
#define FASTABUFFER_H

#include <stdbool.h>
#include "core/arraydef.h"
#include "core/filelengthvalues.h"
#include "core/queue.h"
#include "core/str_array.h"
#include "core/symboldef.h"

typedef struct GtFastaBuffer GtFastaBuffer;

GtFastaBuffer* gt_fastabuffer_new(const GtStrArray *filenametab,
                                  const GtUchar *symbolmap,
                                  bool plainformat,
                                  Filelengthvalues **filelengthtab,
                                  GtQueue *descptr,
                                  unsigned long *characterdistribution);
static int   gt_fastabuffer_next(GtFastaBuffer*, GtUchar *val, GtError*);
void         gt_fastabuffer_delete(GtFastaBuffer*);

#include "fastabuffer_imp.h"

#endif
